@@ -84,6 +84,8 @@ function ofdm_ldpc_rx(filename, mode="700D", varargin)
 
   % main loop ----------------------------------------------------------------
 
+  rx = ofdm_rx_filter(states, mode, rx);
+  
   f = 1;
   while(prx < Nsam)
 
@@ -138,7 +140,7 @@ function ofdm_ldpc_rx(filename, mode="700D", varargin)
 
         % LDPC decode
 
-        % keep earlier mean amplitude estimator for compatability with 700D
+        % keep earlier mean amplitude estimator for compatibility with 700D
         if states.amp_est_mode == 0
           mean_amp = states.mean_amp;
         else
@@ -151,9 +153,8 @@ function ofdm_ldpc_rx(filename, mode="700D", varargin)
 
         % TODO 2020 support for padding with known data bits
 
-        [rx_codeword paritychecks] = ldpc_dec(code_param, mx_iter=100, demod=0, dec=0, ...
-                                              payload_syms_de/mean_amp, EsNo, payload_amps_de/mean_amp);
-        rx_bits = rx_codeword(1:code_param.data_bits_per_frame);
+        [rx_bits paritychecks] = fec_decode(states, code_param, payload_syms_de,...
+                                            payload_amps_de, mean_amp, EsNo);
         errors = xor(payload_bits, rx_bits);
         Nerrs_coded  = sum(errors);
 
@@ -260,7 +261,7 @@ function ofdm_ldpc_rx(filename, mode="700D", varargin)
     figure(7); clf;
     subplot(211)
     stem(Nerrs_log);
-    title('Uncoded errrors/modem frame')
+    title('Uncoded errors/modem frame')
     axis([1 length(Nerrs_log) 0 Nbitsperpacket*0.2]);
     if length(Nerrs_coded_log)
       subplot(212)
@@ -270,7 +271,7 @@ function ofdm_ldpc_rx(filename, mode="700D", varargin)
     end
   end
 
-  figure(9); clf; plot_specgram(rx);
+  figure(9); clf; plot_specgram(rx, Fs=8000, 0, 3000);
 
   if pass_packet_count > 0
     if packet_count >= pass_packet_count printf("Pass!\n"); else printf("Fail!\n"); end;
