@@ -39,7 +39,7 @@ extern char *ofdm_statemode[];
 
 void freedv_700c_open(struct freedv *f) {
     f->snr_squelch_thresh = 0.0;
-    f->squelch_en = 0;
+    f->squelch_en = false;
 
     f->cohpsk = cohpsk_create();
     f->nin = f->nin_prev = COHPSK_NOM_SAMPLES_PER_FRAME;
@@ -47,7 +47,7 @@ void freedv_700c_open(struct freedv *f) {
     f->n_nom_modem_samples = f->n_nat_modem_samples * FREEDV_FS_8000 / COHPSK_FS;// number of samples after native samples are interpolated to 8000 sps
     f->n_max_modem_samples = COHPSK_MAX_SAMPLES_PER_FRAME * FREEDV_FS_8000 / COHPSK_FS + 1;
     f->modem_sample_rate = FREEDV_FS_8000;                                       // note weird sample rate tamed by resampling
-    f->clip_en = 1;
+    f->clip_en = true;
     f->sz_error_pattern = cohpsk_error_pattern_size();
     f->test_frames_diversity = 1;
 
@@ -91,14 +91,14 @@ void freedv_comptx_700c(struct freedv *f, COMP mod_out[]) {
         gain = 2.5;
     }
     for(i=0; i<f->n_nat_modem_samples; i++)
-        mod_out[i] = fcmult(gain*FDMDV_SCALE*NORM_PWR_COHPSK, tx_fdm[i]);
+        mod_out[i] = fcmult(gain*COHPSK_SCALE, tx_fdm[i]);
     i = quisk_cfInterpDecim((complex float *)mod_out, f->n_nat_modem_samples, f->ptFilter7500to8000, 16, 15);
 }
 
 // open function for OFDM voice modes
 void freedv_ofdm_voice_open(struct freedv *f, char *mode) {
     f->snr_squelch_thresh = 0.0;
-    f->squelch_en = 0;
+    f->squelch_en = false;
     struct OFDM_CONFIG *ofdm_config = (struct OFDM_CONFIG *) calloc(1, sizeof (struct OFDM_CONFIG));
     assert(ofdm_config != NULL);
     ofdm_init_mode(mode, ofdm_config);
@@ -117,6 +117,7 @@ void freedv_ofdm_voice_open(struct freedv *f, char *mode) {
     assert(f->ldpc != NULL);
 
     ldpc_codes_setup(f->ldpc, f->ofdm->codename);
+    ldpc_mode_specific_setup(f->ofdm, f->ldpc);
 #ifdef __EMBEDDED__
     f->ldpc->max_iter = 10; /* limit LDPC decoder iterations to limit CPU load */
 #endif
@@ -135,7 +136,7 @@ void freedv_ofdm_voice_open(struct freedv *f, char *mode) {
     f->n_nom_modem_samples = ofdm_get_samples_per_frame(f->ofdm);
     f->n_max_modem_samples = ofdm_get_max_samples_per_frame(f->ofdm);
     f->modem_sample_rate = f->ofdm->config.fs;
-    f->clip_en = 0;
+    f->clip_en = false;
     f->sz_error_pattern = f->ofdm_bitsperframe;
 
     f->tx_bits = NULL; /* not used for 700D */
@@ -171,6 +172,8 @@ void freedv_ofdm_data_open(struct freedv *f) {
     if (f->mode == FREEDV_MODE_DATAC0) strcpy(mode, "datac0");
     if (f->mode == FREEDV_MODE_DATAC1) strcpy(mode, "datac1");
     if (f->mode == FREEDV_MODE_DATAC3) strcpy(mode, "datac3");
+    if (f->mode == FREEDV_MODE_DATAC4) strcpy(mode, "datac4");
+    if (f->mode == FREEDV_MODE_DATAC13) strcpy(mode, "datac13");
 
     ofdm_init_mode(mode, &ofdm_config);
     f->ofdm = ofdm_create(&ofdm_config);
@@ -180,6 +183,7 @@ void freedv_ofdm_data_open(struct freedv *f) {
     f->ldpc = (struct LDPC*)MALLOC(sizeof(struct LDPC));
     assert(f->ldpc != NULL);
     ldpc_codes_setup(f->ldpc, f->ofdm->codename);
+    ldpc_mode_specific_setup(f->ofdm, f->ldpc);
 #ifdef __EMBEDDED__
     f->ldpc->max_iter = 10; /* limit LDPC decoder iterations to limit CPU load */
 #endif
@@ -281,7 +285,7 @@ int freedv_comprx_700c(struct freedv *f, COMP demod_in_8kHz[]) {
     i = quisk_cfInterpDecim((complex float *)demod_in, freedv_nin(f), f->ptFilter8000to7500, 15, 16);
 
     for(i=0; i<f->nin; i++)
-        demod_in[i] = fcmult(1.0/FDMDV_SCALE, demod_in[i]);
+        demod_in[i] = fcmult(1.0/COHPSK_SCALE, demod_in[i]);
 
     float rx_soft_bits[COHPSK_BITS_PER_FRAME];
 
@@ -453,7 +457,8 @@ int freedv_comp_short_rx_ofdm(struct freedv *f, void *demod_in_8kHz, int demod_i
             uint8_t decoded_codeword[Npayloadbitsperpacket];
             symbols_to_llrs(llr, payload_syms_de, payload_amps_de,
                             EsNo, ofdm->mean_amp, Npayloadsymsperpacket);
-            iter = run_ldpc_decoder(ldpc, decoded_codeword, llr, &parityCheckCount);
+            ldpc_decode_frame(ldpc, &parityCheckCount, &iter, decoded_codeword, llr);
+            //iter = run_ldpc_decoder(ldpc, decoded_codeword, llr, &parityCheckCount);
             memcpy(f->rx_payload_bits, decoded_codeword, Ndatabitsperpacket);
 
             if (strlen(ofdm->data_mode)) {
@@ -534,7 +539,7 @@ int freedv_comp_short_rx_ofdm(struct freedv *f, void *demod_in_8kHz, int demod_i
         print_truncated = 1;
     if (print_full) { 
         fprintf(stderr, "%3d nin: %4d st: %-6s euw: %2d %2d mf: %2d f: %5.1f pbw: %d snr: %4.1f eraw: %4d ecdd: %4d iter: %3d "
-                "pcc: %3d rxst: %s\n",
+                "pcc: %4d rxst: %s\n",
                 f->frames++, ofdm->nin,
                 ofdm_statemode[ofdm->last_sync_state],
                 ofdm->uw_errors,
@@ -545,7 +550,7 @@ int freedv_comp_short_rx_ofdm(struct freedv *f, void *demod_in_8kHz, int demod_i
     }
     if (print_truncated) { 
             fprintf(stderr, "%3d nin: %4d st: %-6s euw: %2d %2d mf: %2d f: %5.1f pbw: %d                                        "
-                "         rxst: %s\n",
+                "             rxst: %s\n",
                 f->frames++, ofdm->nin,
                 ofdm_statemode[ofdm->last_sync_state],
                 ofdm->uw_errors,
