@@ -44,8 +44,9 @@ struct MBEST {
 
 struct MBEST *mbest_create(int entries);
 void mbest_destroy(struct MBEST *mbest);
+void mbest_precompute_weight(float cb[], float w[], int k, int m);
 void mbest_insert(struct MBEST *mbest, int index[], float error);
-void mbest_search(const float  *cb, float vec[], float w[], int k, int m, struct MBEST *mbest, int index[]);
+void mbest_search(const float  *cb, float vec[], int k, int m, struct MBEST *mbest, int index[]);
 void mbest_search450(const float  *cb, float vec[], float w[], int k,int shorterK, int m, struct MBEST *mbest, int index[]);
 
 void mbest_print(char title[], struct MBEST *mbest);
